@@ -41,7 +41,6 @@ _CREDENTIALS_WAIT_RETRIES = 10
 _CREDENTIALS_WAIT_PERIOD = 3
 _STORAGE_EXCLUDED_KEYS = {'logs'}
 _UNPROCESSED_DATA_STORE_SUFFIX = 'UNPROCESSED'
-_DATETIME_FORMAT = '%Y.%m.%d_%H.%M.%S_%f'
 
 
 def _store_logs(introspection_data, node_info):
@@ -58,10 +57,16 @@ def _store_logs(introspection_data, node_info):
                     data=introspection_data, node_info=node_info)
         return
 
-    time_fmt = datetime.datetime.utcnow().strftime(_DATETIME_FORMAT)
-    bmc_address = (utils.get_ipmi_address_from_data(introspection_data)
-                   or 'unknown')
-    file_name = 'bmc_%s_%s' % (bmc_address, time_fmt)
+    fmt_args = {
+        'uuid': node_info.uuid if node_info is not None else 'unknown',
+        'mac': (utils.get_pxe_mac(introspection_data) or
+                'unknown').replace(':', ''),
+        'dt': datetime.datetime.utcnow(),
+        'bmc': (utils.get_ipmi_address_from_data(introspection_data) or
+                'unknown')
+    }
+
+    file_name = CONF.processing.ramdisk_logs_filename_format.format(**fmt_args)
 
     try:
         if not os.path.exists(CONF.processing.ramdisk_logs_dir):
@@ -234,7 +239,8 @@ def process(introspection_data):
                                 'error': exc}
         node_info.finished(error=msg)
         _store_logs(introspection_data, node_info)
-        raise utils.Error(msg, node_info=node_info, data=introspection_data)
+        raise utils.Error(msg, node_info=node_info, data=introspection_data,
+                          code=500)
 
     if CONF.processing.always_store_ramdisk_logs:
         _store_logs(introspection_data, node_info)
@@ -286,10 +292,10 @@ def _finish_set_ipmi_credentials(ironic, node, node_info, introspection_data,
               'value': new_username},
              {'op': 'add', 'path': '/driver_info/ipmi_password',
               'value': new_password}]
-    if (not ir_utils.get_ipmi_address(node) and
-            introspection_data.get('ipmi_address')):
+    new_ipmi_address = utils.get_ipmi_address_from_data(introspection_data)
+    if not ir_utils.get_ipmi_address(node) and new_ipmi_address:
         patch.append({'op': 'add', 'path': '/driver_info/ipmi_address',
-                      'value': introspection_data['ipmi_address']})
+                      'value': new_ipmi_address})
     node_info.patch(patch)
 
     for attempt in range(_CREDENTIALS_WAIT_RETRIES):
