@@ -24,7 +24,7 @@ import unittest
 
 import mock
 from oslo_config import cfg
-from oslo_utils import units
+from oslo_config import fixture as config_fixture
 import requests
 
 from ironic_inspector.common import ironic as ir_utils
@@ -54,6 +54,19 @@ connection = sqlite:///%(db_file)s
 
 
 DEFAULT_SLEEP = 2
+TEST_CONF_FILE = None
+
+
+def get_test_conf_file():
+    global TEST_CONF_FILE
+    if not TEST_CONF_FILE:
+        d = tempfile.mkdtemp()
+        TEST_CONF_FILE = os.path.join(d, 'test.conf')
+        db_file = os.path.join(d, 'test.db')
+        with open(TEST_CONF_FILE, 'wb') as fp:
+            content = CONF % {'db_file': db_file}
+            fp.write(content.encode('utf-8'))
+    return TEST_CONF_FILE
 
 
 class Base(base.NodeTest):
@@ -70,62 +83,12 @@ class Base(base.NodeTest):
         self.cli.node.update.return_value = self.node
         self.cli.node.list.return_value = [self.node]
 
-        # https://github.com/openstack/ironic-inspector/blob/master/HTTP-API.rst  # noqa
-        self.data = {
-            'boot_interface': '01-' + self.macs[0].replace(':', '-'),
-            'inventory': {
-                'interfaces': [
-                    {'name': 'eth1', 'mac_address': self.macs[0],
-                     'ipv4_address': '1.2.1.2'},
-                    {'name': 'eth2', 'mac_address': '12:12:21:12:21:12'},
-                    {'name': 'eth3', 'mac_address': self.macs[1],
-                     'ipv4_address': '1.2.1.1'},
-                ],
-                'disks': [
-                    {'name': '/dev/sda', 'model': 'Big Data Disk',
-                     'size': 1000 * units.Gi},
-                    {'name': '/dev/sdb', 'model': 'Small OS Disk',
-                     'size': 20 * units.Gi},
-                ],
-                'cpu': {
-                    'count': 4,
-                    'architecture': 'x86_64'
-                },
-                'memory': {
-                    'physical_mb': 12288
-                },
-                'bmc_address': self.bmc_address
-            },
-            'root_disk': {'name': '/dev/sda', 'model': 'Big Data Disk',
-                          'size': 1000 * units.Gi,
-                          'wwn': None},
-        }
-        self.data_old_ramdisk = {
-            'cpus': 4,
-            'cpu_arch': 'x86_64',
-            'memory_mb': 12288,
-            'local_gb': 464,
-            'interfaces': {
-                'eth1': {'mac': self.macs[0], 'ip': '1.2.1.2'},
-                'eth2': {'mac': '12:12:21:12:21:12'},
-                'eth3': {'mac': self.macs[1], 'ip': '1.2.1.1'},
-            },
-            'boot_interface': '01-' + self.macs[0].replace(':', '-'),
-            'ipmi_address': self.bmc_address,
-        }
-
         self.patch = [
             {'op': 'add', 'path': '/properties/cpus', 'value': '4'},
             {'path': '/properties/cpu_arch', 'value': 'x86_64', 'op': 'add'},
             {'op': 'add', 'path': '/properties/memory_mb', 'value': '12288'},
             {'path': '/properties/local_gb', 'value': '999', 'op': 'add'}
         ]
-        self.patch_old_ramdisk = [
-            {'op': 'add', 'path': '/properties/cpus', 'value': '4'},
-            {'path': '/properties/cpu_arch', 'value': 'x86_64', 'op': 'add'},
-            {'op': 'add', 'path': '/properties/memory_mb', 'value': '12288'},
-            {'path': '/properties/local_gb', 'value': '464', 'op': 'add'}
-        ]
         self.patch_root_hints = [
             {'op': 'add', 'path': '/properties/cpus', 'value': '4'},
             {'path': '/properties/cpu_arch', 'value': 'x86_64', 'op': 'add'},
@@ -135,6 +98,10 @@ class Base(base.NodeTest):
 
         self.node.power_state = 'power off'
 
+        self.cfg = self.useFixture(config_fixture.Config())
+        conf_file = get_test_conf_file()
+        self.cfg.set_config_files([conf_file])
+
     def call(self, method, endpoint, data=None, expect_error=None,
              api_version=None):
         if data is not None:
@@ -211,27 +178,6 @@ class Test(Base):
         status = self.call_get_status(self.uuid)
         self.assertEqual({'finished': True, 'error': None}, status)
 
-    def test_old_ramdisk(self):
-        self.call_introspect(self.uuid)
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-        self.cli.node.set_power_state.assert_called_once_with(self.uuid,
-                                                              'reboot')
-
-        status = self.call_get_status(self.uuid)
-        self.assertEqual({'finished': False, 'error': None}, status)
-
-        res = self.call_continue(self.data_old_ramdisk)
-        self.assertEqual({'uuid': self.uuid}, res)
-        eventlet.greenthread.sleep(DEFAULT_SLEEP)
-
-        self.assertCalledWithPatch(self.patch_old_ramdisk,
-                                   self.cli.node.update)
-        self.cli.port.create.assert_called_once_with(
-            node_uuid=self.uuid, address='11:22:33:44:55:66')
-
-        status = self.call_get_status(self.uuid)
-        self.assertEqual({'finished': True, 'error': None}, status)
-
     def test_setup_ipmi(self):
         patch_credentials = [
             {'op': 'add', 'path': '/driver_info/ipmi_username',
@@ -463,7 +409,7 @@ class Test(Base):
 
         res = self.call_reapply(self.uuid)
         self.assertEqual(202, res.status_code)
-        self.assertEqual(b'', res.text)
+        self.assertEqual('', res.text)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         # reapply request data
@@ -491,7 +437,7 @@ class Test(Base):
         get_mock.return_value = ramdisk_data
         res = self.call_reapply(self.uuid)
         self.assertEqual(202, res.status_code)
-        self.assertEqual(b'', res.text)
+        self.assertEqual('', res.text)
         eventlet.greenthread.sleep(DEFAULT_SLEEP)
 
         # reapply saves the result
@@ -504,12 +450,7 @@ class Test(Base):
 def mocked_server():
     d = tempfile.mkdtemp()
     try:
-        conf_file = os.path.join(d, 'test.conf')
-        db_file = os.path.join(d, 'test.db')
-        with open(conf_file, 'wb') as fp:
-            content = CONF % {'db_file': db_file}
-            fp.write(content.encode('utf-8'))
-
+        conf_file = get_test_conf_file()
         with mock.patch.object(ir_utils, 'get_client'):
             dbsync.main(args=['--config-file', conf_file, 'upgrade'])
 
