@@ -43,24 +43,9 @@ class BaseTest(test_base.NodeTest):
     def setUp(self):
         super(BaseTest, self).setUp()
         self.started_at = time.time()
-        self.pxe_mac = self.macs[1]
-        self.data = {
-            'ipmi_address': self.bmc_address,
-            'cpus': 2,
-            'cpu_arch': 'x86_64',
-            'memory_mb': 1024,
-            'local_gb': 20,
-            'interfaces': {
-                'em1': {'mac': self.macs[0], 'ip': '1.2.0.1'},
-                'em2': {'mac': self.macs[1], 'ip': '1.2.0.2'},
-                'em3': {'mac': 'DE:AD:BE:EF:DE:AD'},
-            },
-            'boot_interface': '01-' + self.pxe_mac.replace(':', '-'),
-        }
         self.all_ports = [mock.Mock(uuid=uuidutils.generate_uuid(),
                                     address=mac) for mac in self.macs]
         self.ports = [self.all_ports[1]]
-        self.all_macs = self.macs + ['DE:AD:BE:EF:DE:AD']
         self.fake_result_json = 'node json'
 
         self.cli_fixture = self.useFixture(
@@ -94,10 +79,6 @@ class TestProcess(BaseProcessTest):
 
         self.assertEqual(self.fake_result_json, res)
 
-        # Only boot interface is added by default
-        self.assertEqual(['em2'], sorted(self.data['interfaces']))
-        self.assertEqual([self.pxe_mac], self.data['macs'])
-
         self.find_mock.assert_called_once_with(bmc_address=self.bmc_address,
                                                mac=mock.ANY)
         actual_macs = self.find_mock.call_args[1]['mac']
@@ -107,7 +88,7 @@ class TestProcess(BaseProcessTest):
             self.node, self.data, self.node_info)
 
     def test_no_ipmi(self):
-        del self.data['ipmi_address']
+        del self.inventory['bmc_address']
         process.process(self.data)
 
         self.find_mock.assert_called_once_with(bmc_address=None, mac=mock.ANY)
@@ -119,7 +100,6 @@ class TestProcess(BaseProcessTest):
 
     def test_not_found_in_cache(self):
         self.find_mock.side_effect = utils.Error('not found')
-
         self.assertRaisesRegexp(utils.Error,
                                 'not found',
                                 process.process, self.data)
@@ -154,9 +134,11 @@ class TestProcess(BaseProcessTest):
     def test_unexpected_exception(self):
         self.process_mock.side_effect = RuntimeError('boom')
 
-        self.assertRaisesRegexp(utils.Error, 'Unexpected exception',
-                                process.process, self.data)
+        with self.assertRaisesRegexp(utils.Error,
+                                     'Unexpected exception') as ctx:
+            process.process(self.data)
 
+        self.assertEqual(500, ctx.exception.http_code)
         self.node_info.finished.assert_called_once_with(
             error='Unexpected exception RuntimeError during processing: boom')
 
@@ -276,13 +258,15 @@ class TestStoreLogs(BaseProcessTest):
         self.logs = b'test logs'
         self.data['logs'] = base64.b64encode(self.logs)
 
-    def _check_contents(self):
+    def _check_contents(self, name=None):
         files = os.listdir(self.tempdir)
         self.assertEqual(1, len(files))
         filename = files[0]
-        self.assertTrue(filename.startswith('bmc_%s_' % self.bmc_address),
-                        '%s does not start with bmc_%s'
-                        % (filename, self.bmc_address))
+        if name is None:
+            self.assertTrue(filename.startswith(self.uuid),
+                            '%s does not start with uuid' % filename)
+        else:
+            self.assertEqual(name, filename)
         with open(os.path.join(self.tempdir, filename), 'rb') as fp:
             self.assertEqual(self.logs, fp.read())
 
@@ -341,6 +325,16 @@ class TestStoreLogs(BaseProcessTest):
         self.assertRaises(utils.Error, process.process, self.data)
         self._check_contents()
 
+    def test_store_custom_name(self, hook_mock):
+        CONF.set_override('ramdisk_logs_filename_format',
+                          '{uuid}-{bmc}-{mac}',
+                          'processing')
+        self.process_mock.side_effect = utils.Error('boom')
+        self.assertRaises(utils.Error, process.process, self.data)
+        self._check_contents(name='%s-%s-%s' % (self.uuid,
+                                                self.bmc_address,
+                                                self.pxe_mac.replace(':', '')))
+
 
 class TestProcessNode(BaseTest):
     def setUp(self):
@@ -350,15 +344,8 @@ class TestProcessNode(BaseTest):
                           'processing')
         self.validate_attempts = 5
         self.data['macs'] = self.macs  # validate_interfaces hook
-        self.data['all_interfaces'] = self.data['interfaces']
         self.ports = self.all_ports
 
-        self.patch_props = [
-            {'path': '/properties/cpus', 'value': '2', 'op': 'add'},
-            {'path': '/properties/cpu_arch', 'value': 'x86_64', 'op': 'add'},
-            {'path': '/properties/memory_mb', 'value': '1024', 'op': 'add'},
-            {'path': '/properties/local_gb', 'value': '20', 'op': 'add'}
-        ]  # scheduler hook
         self.new_creds = ('user', 'password')
         self.patch_credentials = [
             {'op': 'add', 'path': '/driver_info/ipmi_username',
@@ -406,24 +393,12 @@ class TestProcessNode(BaseTest):
                                              address=self.macs[0])
         self.cli.port.create.assert_any_call(node_uuid=self.uuid,
                                              address=self.macs[1])
-        self.assertCalledWithPatch(self.patch_props, self.cli.node.update)
         self.cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
         self.assertFalse(self.cli.node.validate.called)
 
         post_hook_mock.assert_called_once_with(self.data, self.node_info)
         finished_mock.assert_called_once_with(mock.ANY)
 
-    def test_overwrite_disabled(self):
-        CONF.set_override('overwrite_existing', False, 'processing')
-        patch = [
-            {'op': 'add', 'path': '/properties/cpus', 'value': '2'},
-            {'op': 'add', 'path': '/properties/memory_mb', 'value': '1024'},
-        ]
-
-        process._process_node(self.node, self.data, self.node_info)
-
-        self.assertCalledWithPatch(patch, self.cli.node.update)
-
     def test_port_failed(self):
         self.cli.port.create.side_effect = (
             [exceptions.Conflict()] + self.ports[1:])
@@ -434,7 +409,6 @@ class TestProcessNode(BaseTest):
                                              address=self.macs[0])
         self.cli.port.create.assert_any_call(node_uuid=self.uuid,
                                              address=self.macs[1])
-        self.assertCalledWithPatch(self.patch_props, self.cli.node.update)
 
     def test_set_ipmi_credentials(self):
         self.node_info.set_option('new_ipmi_credentials', self.new_creds)
@@ -486,7 +460,6 @@ class TestProcessNode(BaseTest):
         process._process_node(self.node, self.data, self.node_info)
 
         self.cli.node.set_power_state.assert_called_once_with(self.uuid, 'off')
-        self.assertCalledWithPatch(self.patch_props, self.cli.node.update)
         finished_mock.assert_called_once_with(
             mock.ANY,
             error='Failed to power off node %s, check its power '
@@ -517,22 +490,19 @@ class TestProcessNode(BaseTest):
         swift_conn.create_object.assert_called_once_with(name, mock.ANY)
         self.assertEqual(expected,
                          json.loads(swift_conn.create_object.call_args[0][1]))
-        self.assertCalledWithPatch(self.patch_props, self.cli.node.update)
 
     @mock.patch.object(process.swift, 'SwiftAPI', autospec=True)
     def test_store_data_no_logs(self, swift_mock):
         CONF.set_override('store_data', 'swift', 'processing')
         swift_conn = swift_mock.return_value
         name = 'inspector_data-%s' % self.uuid
-        expected = self.data.copy()
         self.data['logs'] = 'something'
 
         process._process_node(self.node, self.data, self.node_info)
 
         swift_conn.create_object.assert_called_once_with(name, mock.ANY)
-        self.assertEqual(expected,
+        self.assertNotIn('logs',
                          json.loads(swift_conn.create_object.call_args[0][1]))
-        self.assertCalledWithPatch(self.patch_props, self.cli.node.update)
 
     @mock.patch.object(process.swift, 'SwiftAPI', autospec=True)
     def test_store_data_location(self, swift_mock):
@@ -541,11 +511,8 @@ class TestProcessNode(BaseTest):
                           'processing')
         swift_conn = swift_mock.return_value
         name = 'inspector_data-%s' % self.uuid
-        self.patch_props.append(
-            {'path': '/extra/inspector_data_object',
-             'value': name,
-             'op': 'add'}
-        )
+        patch = [{'path': '/extra/inspector_data_object',
+                  'value': name, 'op': 'add'}]
         expected = self.data
 
         process._process_node(self.node, self.data, self.node_info)
@@ -553,7 +520,7 @@ class TestProcessNode(BaseTest):
         swift_conn.create_object.assert_called_once_with(name, mock.ANY)
         self.assertEqual(expected,
                          json.loads(swift_conn.create_object.call_args[0][1]))
-        self.assertCalledWithPatch(self.patch_props, self.cli.node.update)
+        self.cli.node.update.assert_any_call(self.uuid, patch)
 
 
 @mock.patch.object(process, '_reapply', autospec=True)
@@ -614,7 +581,6 @@ class TestReapplyNode(BaseTest):
                           'processing')
         CONF.set_override('store_data', 'swift', 'processing')
         self.data['macs'] = self.macs
-        self.data['all_interfaces'] = self.data['interfaces']
         self.ports = self.all_ports
         self.node_info = node_cache.NodeInfo(uuid=self.uuid,
                                              started_at=self.started_at,
@@ -667,8 +633,7 @@ class TestReapplyNode(BaseTest):
         finished_mock.assert_called_once_with(self.node_info)
 
         # asserting validate_interfaces was called
-        self.assertEqual({'em2': self.data['interfaces']['em2']},
-                         swifted_data['interfaces'])
+        self.assertEqual(self.pxe_interfaces, swifted_data['interfaces'])
         self.assertEqual([self.pxe_mac], swifted_data['macs'])
 
         # assert ports were created with whatever there was left
